@@ -1,10 +1,14 @@
 import os
 import re
-import sre_constants
 import sys
 from pathlib import Path
 from typing import Dict, List, Union
 
+try:  # Python >= 3.11
+    import re._constants as sre_constants
+except ImportError:
+    import sre_constants
+
 from prospector import tools
 from prospector.autodetect import autodetect_libraries
 from prospector.compat import is_relative_to
