@@ -1,7 +1,11 @@
 import re
-import sre_constants
 from pathlib import Path
 
+try:  # Python >= 3.11
+    import re._constants as sre_constants
+except ImportError:
+    import sre_constants
+
 import yaml
 
 from prospector.finder import FileFinder
